@@ -1010,8 +1010,10 @@ path <- function(...) {
     }
     toadd <- as.igraph.vs(e1, toadd)
     lt <- length(toadd)
-    if (lt >= 2) {
+    if (lt > 2) {
       toadd <- c(toadd[1], rep(toadd[2:(lt-1)], each=2), toadd[lt])
+      res <- add_edges(e1, toadd, attr=attr)
+	  } else if (lt == 2) {
       res <- add_edges(e1, toadd, attr=attr)
     } else {
       res <- e1
